library(testthat)
library(survParamSim)

# options(lifecycle_verbosity = "error")
test_check("survParamSim")
